@@ -648,7 +648,7 @@ new_window_show_callback (GtkWidget *widget,
         
         window = NAUTILUS_WINDOW (user_data);
         
-        gtk_widget_destroy (GTK_WIDGET (window));
+        nautilus_window_close (window);
 
         g_signal_handlers_disconnect_by_func (widget, 
                                               G_CALLBACK (new_window_show_callback),
@@ -672,7 +672,7 @@ open_location (NautilusWindow *window,
         case Nautilus_ViewFrame_OPEN_ACCORDING_TO_MODE :
 		if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
 			target_window = window;
-			if (NAUTILUS_IS_DESKTOP_WINDOW (window)) {
+			if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
 				if (!NAUTILUS_SPATIAL_WINDOW (window)->affect_spatial_window_on_next_location_change) {
 					target_window = nautilus_application_create_navigation_window 
 						(window->application,
@@ -685,6 +685,7 @@ open_location (NautilusWindow *window,
                         if (!NAUTILUS_SPATIAL_WINDOW (window)->affect_spatial_window_on_next_location_change) {
                                 target_window = nautilus_application_present_spatial_window (
                                         window->application,
+					window,
                                         location,
                                         gtk_window_get_screen (GTK_WINDOW (window)));
                                 do_load_location = FALSE;
@@ -699,6 +700,7 @@ open_location (NautilusWindow *window,
         case Nautilus_ViewFrame_OPEN_IN_SPATIAL :
                 target_window = nautilus_application_present_spatial_window (
                         window->application,
+			window,
                         location,
                         gtk_window_get_screen (GTK_WINDOW (window)));
                 break;
@@ -717,7 +719,7 @@ open_location (NautilusWindow *window,
         if ((flags & Nautilus_ViewFrame_OPEN_FLAG_CLOSE_BEHIND) != 0) {
                 if (NAUTILUS_IS_SPATIAL_WINDOW (window) && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
                         if (GTK_WIDGET_VISIBLE (target_window)) {
-                                gtk_widget_destroy (GTK_WIDGET (window));
+                                nautilus_window_close (window);
                         } else {
                                 g_signal_connect_object (target_window,
                                                          "show",
@@ -745,11 +747,19 @@ open_location (NautilusWindow *window,
 
 void
 nautilus_window_open_location (NautilusWindow *window,
-                               const char *location)
+                               const char *location,
+                               gboolean close_behind)
 {
-        open_location (window, location, 
+	Nautilus_ViewFrame_OpenFlags flags;
+
+	flags = 0;
+	if (close_behind) {
+		flags = Nautilus_ViewFrame_OPEN_FLAG_CLOSE_BEHIND;
+	}
+	
+	open_location (window, location,
                        Nautilus_ViewFrame_OPEN_ACCORDING_TO_MODE,
-                       0, NULL);
+                       flags, NULL);
 }
 
 void
@@ -1197,8 +1207,8 @@ position_and_show_window_callback (NautilusFile *file,
                         eel_gtk_window_set_initial_geometry_from_string 
                                 (GTK_WINDOW (window), 
                                  geometry_string,
-                                 NAUTILUS_WINDOW_MIN_WIDTH, 
-                                 NAUTILUS_WINDOW_MIN_HEIGHT,
+                                 NAUTILUS_SPATIAL_WINDOW_MIN_WIDTH, 
+                                 NAUTILUS_SPATIAL_WINDOW_MIN_HEIGHT,
 				 pending_location_already_showing (window));
                 }
                 g_free (geometry_string);
